@@ -2,7 +2,6 @@ from collections import defaultdict
 from types import FunctionType
 
 import numpy as np
-import pandas as pd
 import param
 
 from ..core import Dataset, Dimension, Element2D
@@ -21,9 +20,9 @@ from .util import (
 
 
 class RedimGraph(Redim):
-    """
-    Extension for the redim utility that allows re-dimensioning
+    """Extension for the redim utility that allows re-dimensioning
     Graph objects including their nodes and edgepaths.
+
     """
 
     def __call__(self, specs=None, **dimensions):
@@ -37,11 +36,11 @@ class RedimGraph(Redim):
 
 
 class layout_nodes(Operation):
-    """
-    Accepts a Graph and lays out the corresponding nodes with the
+    """Accepts a Graph and lays out the corresponding nodes with the
     supplied networkx layout function. If no layout function is
     supplied uses a simple circular_layout function. Also supports
     LayoutAlgorithm function provided in datashader layouts.
+
     """
 
     only_nodes = param.Boolean(default=False, doc="""
@@ -60,7 +59,7 @@ class layout_nodes(Operation):
             graph = nx.from_edgelist(edges)
             if 'weight' in self.p.kwargs:
                 weight = self.p.kwargs['weight']
-                for (s, t), w in zip(edges, element[weight]):
+                for (s, t), w in zip(edges, element[weight], strict=None):
                     graph.edges[s, t][weight] = w
             positions = self.p.layout(graph, **self.p.kwargs)
             nodes = [(*pos, idx) for idx, pos in sorted(positions.items())]
@@ -69,6 +68,7 @@ class layout_nodes(Operation):
             target = element.dimension_values(1, expanded=False)
             nodes = np.unique(np.concatenate([source, target]))
             if self.p.layout:
+                import pandas as pd
                 df = pd.DataFrame({'index': nodes})
                 nodes = self.p.layout(df, element.dframe(), **self.p.kwargs)
                 nodes = nodes[['x', 'y', 'index']]
@@ -85,10 +85,10 @@ class layout_nodes(Operation):
 
 
 class Nodes(Points):
-    """
-    Nodes is a simple Element representing Graph nodes as a set of
+    """Nodes is a simple Element representing Graph nodes as a set of
     Points.  Unlike regular Points, Nodes must define a third key
     dimension corresponding to the node index.
+
     """
 
     kdims = param.List(default=[Dimension('x'), Dimension('y'),
@@ -98,17 +98,16 @@ class Nodes(Points):
 
 
 class EdgePaths(Path):
-    """
-    EdgePaths is a simple Element representing the paths of edges
+    """EdgePaths is a simple Element representing the paths of edges
     connecting nodes in a graph.
+
     """
 
     group = param.String(default='EdgePaths', constant=True)
 
 
 class Graph(Dataset, Element2D):
-    """
-    Graph is high-level Element representing both nodes and edges.
+    """Graph is high-level Element representing both nodes and edges.
     A Graph may be defined in an abstract form representing just
     the abstract edges between nodes and optionally may be made
     concrete by supplying a Nodes Element defining the concrete
@@ -119,6 +118,7 @@ class Graph(Dataset, Element2D):
     The constructor accepts regular columnar data defining the edges
     or a tuple of the abstract edges and nodes, or a tuple of the
     abstract edges, nodes, and edgepaths.
+
     """
 
     group = param.String(default='Graph', constant=True)
@@ -165,10 +165,12 @@ class Graph(Dataset, Element2D):
         return RedimGraph(self, mode='dataset')
 
     def _add_node_info(self, node_info):
+        import pandas as pd
+
         nodes = self.nodes.clone(datatype=['pandas', 'dictionary'])
         if isinstance(node_info, self.node_type):
             nodes = nodes.redim(**dict(zip(nodes.dimensions('key', label=True),
-                                           node_info.kdims)))
+                                           node_info.kdims, strict=None)))
 
         if not node_info.kdims and len(node_info) != len(nodes):
             raise ValueError("The supplied node data does not match "
@@ -194,7 +196,7 @@ class Graph(Dataset, Element2D):
         node_info_df = node_info_df[cols]
         node_df = pd.merge(node_df, node_info_df, left_on=left_on,
                             right_on=idx.name, how='left')
-        nodes = nodes.clone(node_df, kdims=nodes.kdims[:2]+[idx],
+        nodes = nodes.clone(node_df, kdims=[*nodes.kdims[:2], idx],
                             vdims=node_info.vdims)
 
         self._nodes = nodes
@@ -204,7 +206,7 @@ class Graph(Dataset, Element2D):
         if self._edgepaths is None:
             return
         mismatch = []
-        for kd1, kd2 in zip(self.nodes.kdims, self.edgepaths.kdims):
+        for kd1, kd2 in zip(self.nodes.kdims, self.edgepaths.kdims, strict=None):
             if kd1 != kd2:
                 mismatch.append(f'{kd1} != {kd2}')
         if mismatch:
@@ -241,8 +243,7 @@ class Graph(Dataset, Element2D):
                              *args, **overrides)
 
     def select(self, selection_expr=None, selection_specs=None, selection_mode='edges', **selection):
-        """
-        Allows selecting data by the slices, sets and scalar values
+        """Allows selecting data by the slices, sets and scalar values
         along a particular dimension. The indices should be supplied as
         keywords mapping between the selected dimension and
         value. Additionally selection_specs (taking the form of a list
@@ -253,13 +254,14 @@ class Graph(Dataset, Element2D):
         Selecting by a node dimensions selects all edges and nodes that are
         connected to the selected nodes. To select only edges between the
         selected nodes set the selection_mode to 'nodes'.
+
         """
         from ..util.transform import dim
         if selection_expr is not None and not isinstance(selection_expr, dim):
             raise ValueError("""\
-The first positional argument to the Dataset.select method is expected to be a
-holoviews.util.transform.dim expression. Use the selection_specs keyword
-argument to specify a selection specification""")
+            The first positional argument to the Dataset.select method is expected to be a
+            holoviews.util.transform.dim expression. Use the selection_specs keyword
+            argument to specify a selection specification""")
 
         sel_dims = (*self.dimensions('ranges'), 'selection_mask')
         selection = {dim: sel for dim, sel in selection.items() if dim in sel_dims}
@@ -356,11 +358,10 @@ argument to specify a selection specification""")
 
     @property
     def nodes(self):
-        """
-        Computes the node positions the first time they are requested
+        """Computes the node positions the first time they are requested
         if no explicit node information was supplied.
-        """
 
+        """
         if self._nodes is None:
             from ..operation.element import chain
             self._nodes = layout_nodes(self, only_nodes=True)
@@ -370,9 +371,9 @@ argument to specify a selection specification""")
 
     @property
     def edgepaths(self):
-        """
-        Returns the fixed EdgePaths or computes direct connections
+        """Returns the fixed EdgePaths or computes direct connections
         between supplied nodes.
+
         """
         if self._edgepaths:
             return self._edgepaths
@@ -381,8 +382,7 @@ argument to specify a selection specification""")
 
     @classmethod
     def from_networkx(cls, G, positions, nodes=None, **kwargs):
-        """
-        Generate a HoloViews Graph from a networkx.Graph object and
+        """Generate a HoloViews Graph from a networkx.Graph object and
         networkx layout function or dictionary of node positions.
         Any keyword arguments will be passed to the layout
         function. By default it will extract all node and edge
@@ -390,16 +390,21 @@ argument to specify a selection specification""")
         information may also be supplied. Any non-scalar attributes,
         such as lists or dictionaries will be ignored.
 
-        Args:
-            G (networkx.Graph): Graph to convert to Graph element
-            positions (dict or callable): Node positions
-                Node positions defined as a dictionary mapping from
-                node id to (x, y) tuple or networkx layout function
-                which computes a positions dictionary
-            kwargs (dict): Keyword arguments for layout function
+        Parameters
+        ----------
+        G : networkx.Graph
+            Graph to convert to Graph element
+        positions : dict or callable
+            Node positions
+            Node positions defined as a dictionary mapping from
+            node id to (x, y) tuple or networkx layout function
+            which computes a positions dictionary
+        kwargs : dict
+            Keyword arguments for layout function
 
-        Returns:
-            Graph element
+        Returns
+        -------
+        Graph element
         """
         if not isinstance(positions, dict):
             positions = positions(G, **kwargs)
@@ -429,8 +434,8 @@ argument to specify a selection specification""")
         if nodes:
             node_columns = nodes.columns()
             idx_dim = nodes.kdims[0].name
-            info_cols, values = zip(*((k, v) for k, v in node_columns.items() if k != idx_dim))
-            node_info = {i: vals for i, vals in zip(node_columns[idx_dim], zip(*values))}
+            info_cols, values = zip(*((k, v) for k, v in node_columns.items() if k != idx_dim), strict=None)
+            node_info = {i: vals for i, vals in zip(node_columns[idx_dim], zip(*values, strict=None), strict=None)}
         else:
             info_cols = []
             node_info = None
@@ -475,8 +480,7 @@ argument to specify a selection specification""")
 
 
 class TriMesh(Graph):
-    """
-    A TriMesh represents a mesh of triangles represented as the
+    """A TriMesh represents a mesh of triangles represented as the
     simplices and nodes. The simplices represent a indices into the
     nodes array. The mesh therefore follows a datastructure very
     similar to a graph, with the abstract connectivity between nodes
@@ -486,6 +490,7 @@ class TriMesh(Graph):
 
     Unlike a Graph each simplex is represented as the node indices of
     the three corners of each triangle.
+
     """
 
     kdims = param.List(default=['node1', 'node2', 'node3'],
@@ -541,9 +546,9 @@ class TriMesh(Graph):
 
     @classmethod
     def from_vertices(cls, data):
-        """
-        Uses Delauney triangulation to compute triangle simplices for
+        """Uses Delauney triangulation to compute triangle simplices for
         each point.
+
         """
         try:
             from scipy.spatial import Delaunay
@@ -558,8 +563,8 @@ class TriMesh(Graph):
         return cls((tris.simplices, data))
 
     def _initialize_edgepaths(self):
-        """
-        Returns the EdgePaths by generating a triangle for each simplex.
+        """Returns the EdgePaths by generating a triangle for each simplex.
+
         """
         if self._edgepaths:
             return self._edgepaths
@@ -582,31 +587,31 @@ class TriMesh(Graph):
 
     @property
     def edgepaths(self):
-        """
-        Returns the EdgePaths by generating a triangle for each simplex.
+        """Returns the EdgePaths by generating a triangle for each simplex.
+
         """
         return self._initialize_edgepaths()
 
-    def select(self, selection_specs=None, **selection):
-        """
-        Allows selecting data by the slices, sets and scalar values
+    def select(self, selection_expr=None, selection_specs=None, **selection):
+        """Allows selecting data by the slices, sets and scalar values
         along a particular dimension. The indices should be supplied as
         keywords mapping between the selected dimension and
         value. Additionally selection_specs (taking the form of a list
         of type.group.label strings, types or functions) may be
         supplied, which will ensure the selection is only applied if the
         specs match the selected object.
+
         """
         self._initialize_edgepaths()
-        return super().select(selection_specs=None,
-                              selection_mode='nodes',
-                              **selection)
+        return super().select(
+            selection_expr=selection_expr, selection_specs=selection_specs,
+            selection_mode='nodes', **selection
+        )
 
 
 
 class layout_chords(Operation):
-    """
-    layout_chords computes the locations of each node on a circle and
+    """layout_chords computes the locations of each node on a circle and
     the chords connecting them. The amount of radial angle devoted to
     each node and the number of chords are scaled by the value
     dimension of the Chord element. If the values are integers then
@@ -620,6 +625,7 @@ class layout_chords(Operation):
     source to the target node in the graph, the number of samples to
     interpolate the spline with is given by the chord_samples
     parameter.
+
     """
 
     chord_samples = param.Integer(default=50, bounds=(0, None), doc="""
@@ -658,7 +664,7 @@ class layout_chords(Operation):
 
         # Compute connectivity matrix
         matrix = np.zeros((len(nodes), len(nodes)))
-        for s, t, v in zip(src_idx, tgt_idx, values):
+        for s, t, v in zip(src_idx, tgt_idx, values, strict=None):
             matrix[s, t] += v
 
         # Compute weighted angular slice for each connection
@@ -681,7 +687,7 @@ class layout_chords(Operation):
             n_conn = weights_of_areas[i]
             p0, p1 = points[i], points[i+1]
             angles = np.linspace(p0, p1, int(n_conn))
-            coords = list(zip(np.cos(angles), np.sin(angles)))
+            coords = list(zip(np.cos(angles), np.sin(angles), strict=None))
             all_areas.append(coords)
 
         # Draw each chord by interpolating quadratic splines
@@ -715,7 +721,7 @@ class layout_chords(Operation):
             if isinstance(nodes_el, Nodes):
                 kdims = nodes_el.kdims
             else:
-                kdims = Nodes.kdims[:2]+[idx_dim]
+                kdims = [*Nodes.kdims[:2], idx_dim]
             vdims = [vd for vd in nodes_el.vdims if vd not in kdims]
             values = tuple(nodes_el.dimension_values(vd) for vd in vdims)
         else:
@@ -735,8 +741,7 @@ class layout_chords(Operation):
 
 
 class Chord(Graph):
-    """
-    Chord is a special type of Graph which computes the locations of
+    """Chord is a special type of Graph which computes the locations of
     each node on a circle and the chords connecting them. The amount
     of radial angle devoted to each node and the number of chords are
     scaled by a weight supplied as a value dimension.
@@ -746,6 +751,7 @@ class Chord(Graph):
     chords are apportioned such that the lowest value edge is given
     one chord and all other nodes are given nodes proportional to
     their weight.
+
     """
 
     group = param.String(default='Chord', constant=True)
