@@ -66,9 +66,9 @@ from .util import (
 
 
 class BokehPlot(DimensionedPlot, CallbackPlot):
-    """
-    Plotting baseclass for the Bokeh backends, implementing the basic
+    """Plotting baseclass for the Bokeh backends, implementing the basic
     plotting interface for Bokeh based plots.
+
     """
 
     shared_datasource = param.Boolean(default=True, doc="""
@@ -87,7 +87,15 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
                                             "left", "right", None],
                                    doc="""
         The toolbar location, must be one of 'above', 'below',
-        'left', 'right', None.""")
+        'left', 'right', None.""",
+    )
+
+    autohide_toolbar = param.Boolean(
+        default=False,
+        doc="""
+        Whether to automatically hide the toolbar until the user hovers over the plot.
+        This parameter has no effect if the toolbar is disabled (toolbar=None).""",
+    )
 
     width = param.Integer(default=None, bounds=(0, None), doc="""
         The width of the component (in pixels). This can be either
@@ -118,11 +126,11 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
 
     def get_data(self, element, ranges, style):
-        """
-        Returns the data from an element in the appropriate format for
+        """Returns the data from an element in the appropriate format for
         initializing or updating a ColumnDataSource and a dictionary
         which maps the expected keywords arguments of a glyph to
         the column in the datasource.
+
         """
         raise NotImplementedError
 
@@ -136,8 +144,8 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
                     s.update(index=self.selected)
 
     def _init_datasource(self, data):
-        """
-        Initializes a data source to be passed into the bokeh glyph.
+        """Initializes a data source to be passed into the bokeh glyph.
+
         """
         data = self._postprocess_data(data)
         cds = ColumnDataSource(data=data)
@@ -147,9 +155,9 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
 
     def _postprocess_data(self, data):
-        """
-        Applies necessary type transformation to the data before
+        """Applies necessary type transformation to the data before
         it is set on a ColumnDataSource.
+
         """
         new_data = {}
         for k, values in data.items():
@@ -169,8 +177,8 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
 
     def _update_datasource(self, source, data):
-        """
-        Update datasource with data for a new frame.
+        """Update datasource with data for a new frame.
+
         """
         data = self._postprocess_data(data)
         empty = all(len(v) == 0 for v in data.values())
@@ -198,18 +206,18 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
     @property
     def state(self):
-        """
-        The plotting state that gets updated via the update method and
+        """The plotting state that gets updated via the update method and
         used by the renderer to generate output.
+
         """
         return self.handles['plot']
 
 
     @property
     def current_handles(self):
-        """
-        Should return a list of plot objects that have changed and
+        """Should return a list of plot objects that have changed and
         should be updated.
+
         """
         return []
 
@@ -233,10 +241,10 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
 
     def cleanup(self):
-        """
-        Cleans up references to the plot after the plot has been
+        """Cleans up references to the plot after the plot has been
         deleted. Traverses through all plots cleaning up Callbacks and
         Stream subscribers.
+
         """
         plots = self.traverse(lambda x: x, [BokehPlot])
         for plot in plots:
@@ -264,9 +272,9 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
                 ]
 
     def _fontsize(self, key, label='fontsize', common=True):
-        """
-        Converts integer fontsizes to a string specifying
+        """Converts integer fontsizes to a string specifying
         fontsize in pt.
+
         """
         size = super()._fontsize(key, label, common)
         return {k: v if isinstance(v, str) else f'{v}pt'
@@ -306,9 +314,9 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
         return title_div
 
     def sync_sources(self):
-        """
-        Syncs data sources between Elements, which draw data
+        """Syncs data sources between Elements, which draw data
         from the same object.
+
         """
         get_sources = lambda x: (id(x.current_frame.data), x)
         filter_fn = lambda x: (x.shared_datasource and x.current_frame is not None and
@@ -361,10 +369,10 @@ class BokehPlot(DimensionedPlot, CallbackPlot):
 
 
 class CompositePlot(BokehPlot):
-    """
-    CompositePlot is an abstract baseclass for plot types that draw
+    """CompositePlot is an abstract baseclass for plot types that draw
     render multiple axes. It implements methods to add an overall title
     to such a plot.
+
     """
 
     sizing_mode = param.Selector(default=None, objects=[
@@ -415,9 +423,9 @@ class CompositePlot(BokehPlot):
           {'title': '15pt'}""")
 
     def _link_dimensioned_streams(self):
-        """
-        Should perform any linking required to update titles when dimensioned
+        """Should perform any linking required to update titles when dimensioned
         streams change.
+
         """
         streams = [s for s in self.streams if any(k in self.dimensions for k in s.contents)]
         for s in streams:
@@ -425,24 +433,24 @@ class CompositePlot(BokehPlot):
 
     def _stream_update(self, **kwargs):
         contents = [k for s in self.streams for k in s.contents]
-        key = tuple(None if d in contents else k for d, k in zip(self.dimensions, self.current_key))
+        key = tuple(None if d in contents else k for d, k in zip(self.dimensions, self.current_key, strict=None))
         key = wrap_tuple_streams(key, self.dimensions, self.streams)
         self._get_title_div(key)
 
     @property
     def current_handles(self):
-        """
-        Should return a list of plot objects that have changed and
+        """Should return a list of plot objects that have changed and
         should be updated.
+
         """
         return [self.handles['title']] if 'title' in self.handles else []
 
 
 
 class GridPlot(CompositePlot, GenericCompositePlot):
-    """
-    Plot a group of elements in a grid layout based on a GridSpace element
+    """Plot a group of elements in a grid layout based on a GridSpace element
     object.
+
     """
 
     axis_offset = param.Integer(default=50, doc="""
@@ -671,7 +679,7 @@ class GridPlot(CompositePlot, GenericCompositePlot):
                 r1, r2 = r1[::-1], r2[::-1]
             plot = gridplot([r1, r2], merge_tools=False)
             if self.merge_tools:
-                plot.toolbar = merge_tools([r1, r2])
+                plot.toolbar = merge_tools([r1, r2], autohide=self.autohide_toolbar)
         elif y_axis:
             models = [y_axis, plot]
             if self.shared_yaxis: models = models[::-1]
@@ -685,10 +693,10 @@ class GridPlot(CompositePlot, GenericCompositePlot):
 
     @update_shared_sources
     def update_frame(self, key, ranges=None):
-        """
-        Update the internal state of the Plot to represent the given
+        """Update the internal state of the Plot to represent the given
         key tuple (where integers represent frames). Returns this
         state.
+
         """
         ranges = self.compute_ranges(self.layout, key, ranges)
         for coord in self.layout.keys(full_grid=True):
@@ -777,7 +785,7 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
             # to create the correct subaxes for all plots in the layout
             layout_key, _ = layout_items.get((r, c), (None, None))
             if isinstance(layout, NdLayout) and layout_key:
-                layout_dimensions = dict(zip(layout_dimensions, layout_key))
+                layout_dimensions = dict(zip(layout_dimensions, layout_key, strict=None))
 
             # Generate the axes and create the subplots with the appropriate
             # axis objects, handling any Empty objects.
@@ -805,12 +813,12 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
 
 
     def _create_subplots(self, layout, positions, layout_dimensions, ranges, num=0):
-        """
-        Plot all the views contained in the AdjointLayout Object using axes
+        """Plot all the views contained in the AdjointLayout Object using axes
         appropriate to the layout configuration. All the axes are
         supplied by LayoutPlot - the purpose of the call is to
         invoke subplots with correct options and styles and hide any
         empty axes as necessary.
+
         """
         subplots = {}
         adjoint_clone = layout.clone(shared_data=False, id=layout.id)
@@ -879,9 +887,9 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
 
 
     def _compute_grid(self):
-        """
-        Computes an empty grid to position the plots on by expanding
+        """Computes an empty grid to position the plots on by expanding
         any AdjointLayouts into multiple rows and columns.
+
         """
         widths = []
         for c in range(self.cols):
@@ -978,7 +986,7 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
                                         toolbar_location=self.toolbar,
                                         sizing_mode=sizing_mode)
                         if self.merge_tools:
-                            grid.toolbar = merge_tools(children)
+                            grid.toolbar = merge_tools(children, autohide=self.autohide_toolbar)
                     tab_plots.append((title, grid))
                     continue
 
@@ -1020,7 +1028,7 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
             if self.sync_legends:
                 sync_legends(layout_plot)
             if self.merge_tools:
-                layout_plot.toolbar = merge_tools(plot_grid)
+                layout_plot.toolbar = merge_tools(plot_grid, autohide=self.autohide_toolbar)
 
         title = self._get_title_div(self.keys[-1])
         if title:
@@ -1042,10 +1050,10 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
 
     @update_shared_sources
     def update_frame(self, key, ranges=None):
-        """
-        Update the internal state of the Plot to represent the given
+        """Update the internal state of the Plot to represent the given
         key tuple (where integers represent frames). Returns this
         state.
+
         """
         ranges = self.compute_ranges(self.layout, key, ranges)
         for r, c in self.coords:
@@ -1073,12 +1081,12 @@ class AdjointLayoutPlot(BokehPlot, GenericAdjointLayoutPlot):
         super().__init__(subplots=subplots, **params)
 
     def initialize_plot(self, ranges=None, plots=None):
-        """
-        Plot all the views contained in the AdjointLayout Object using axes
+        """Plot all the views contained in the AdjointLayout Object using axes
         appropriate to the layout configuration. All the axes are
         supplied by LayoutPlot - the purpose of the call is to
         invoke subplots with correct options and styles and hide any
         empty axes as necessary.
+
         """
         if plots is None:
             plots = []
@@ -1094,8 +1102,7 @@ class AdjointLayoutPlot(BokehPlot, GenericAdjointLayoutPlot):
                 passed_plots = plots + adjoined_plots
                 adjoined_plots.append(subplot.initialize_plot(ranges=ranges, plots=passed_plots))
         self.drawn = True
-        if not adjoined_plots: adjoined_plots = [None]
-        return adjoined_plots
+        return adjoined_plots or [None]
 
     def update_frame(self, key, ranges=None):
         plot = None
