@@ -1,20 +1,189 @@
 import sys
 
+import bokeh.core.properties as bp
 import numpy as np
 import param
-from bokeh.models import CustomJSHover, DatetimeAxis
+from bokeh.model import DataModel
+from bokeh.models import CustomJS, CustomJSHover, DatetimeAxis, HoverTool
+from bokeh.models.dom import Div, Span, Styles, ValueOf
+from panel.io import hold
 
+from ...core.data import XArrayInterface
 from ...core.util import cartesian_product, dimension_sanitizer, isfinite
 from ...element import Raster
+from ...util.warnings import warn
 from ..util import categorical_legend
 from .chart import PointPlot
 from .element import ColorbarPlot, LegendPlot
 from .selection import BokehOverlaySelectionDisplay
 from .styles import base_properties, fill_properties, line_properties, mpl_to_bokeh
-from .util import BOKEH_GE_3_3_0, BOKEH_GE_3_4_0, colormesh
+from .util import (
+    BOKEH_GE_3_3_0,
+    BOKEH_GE_3_4_0,
+    BOKEH_GE_3_7_0,
+    BOKEH_VERSION,
+    colormesh,
+)
+
+_EPOCH = np.datetime64("1970-01-01", "ns")
 
 
-class RasterPlot(ColorbarPlot):
+class HoverModel(DataModel):
+    xy = bp.Any()
+    data = bp.Any()
+
+    code_js = """
+    export default ({hover_model, attr, fmt}) => {
+      const templating = Bokeh.require("core/util/templating");
+      const value = hover_model.data[attr];
+      if (fmt == "M") {
+        const formatter = templating.DEFAULT_FORMATTERS.datetime;
+        return formatter(value, "%Y-%m-%d %H:%M:%S")
+      } else {
+        const formatter = templating.get_formatter();
+        return formatter(value)
+      }
+    }; """
+
+
+class ServerHoverMixin(param.Parameterized):
+
+    selector_in_hovertool = param.Boolean(default=True, doc="""
+        Whether to show the selector in HoverTool.""")
+
+    def _update_hover(self, element):
+        tool = self.handles['hover']
+        if 'hv_created' in tool.tags and isinstance(tool.tooltips, Div):
+            self._hover_data = element.data
+            return
+        super()._update_hover(element)
+
+    def _init_tools(self, element, callbacks=None):
+        tools = super()._init_tools(element, callbacks=callbacks)
+
+        hover = None
+        for tool in tools or ():
+            if isinstance(tool, HoverTool):
+                hover = tool
+                break
+
+        data = element.data
+        if (
+            hover is None
+            or "hv_created" not in tool.tags
+            or not (XArrayInterface.applies(data) and "selector_columns" in data.attrs)
+        ):
+            return tools
+
+        if not BOKEH_GE_3_7_0:
+            bk_str = ".".join(map(str, BOKEH_VERSION))
+            msg = f"selector needs Bokeh 3.7 or greater, you are using version {bk_str}."
+            warn(msg, RuntimeWarning)
+            hover.tooltips = Div(children=[msg])
+            return tools
+
+        self._hover_data = data
+
+        # Get dimensions
+        coords, vars = list(data.coords), list(data.data_vars)
+        vars.remove("__index__")
+        ht = self.hover_tooltips or {}
+        if ht:
+            ht = [ht] if isinstance(ht, str) else ht
+            ht = dict([t[::-1] if isinstance(t, tuple) else (t, t) for t in ht])
+            coords = [c for c in coords if c in ht]
+            vars = [v for v in vars if v in ht]
+        elif isinstance(self, RGBPlot):
+            # Remove vdims (RGBA) as they are not very useful
+            for vdim in map(str, element.vdims):
+                if vdim in vars:
+                    vars.remove(vdim)
+
+        hover_model = HoverModel(data={})
+        dims = (*coords, *vars)
+        dtypes = {**data.coords.dtypes, **data.data_vars.dtypes}
+        is_datetime = [dtypes[c].kind == "M" for c in data.coords]
+        def _create_row(attr):
+            kwargs = {
+                "format": "@{custom}",
+                "formatter": CustomJS(
+                    args=dict(hover_model=hover_model, attr=attr, fmt=dtypes[attr].kind),
+                    code=HoverModel.code_js
+                )
+            }
+            return (
+                Span(children=[f"{ht.get(attr, attr)}:"], style={"color": "#26aae1", "text_align": "right"}),
+                Span(children=[ValueOf(obj=hover_model, attr="data", **kwargs)], style={"text_align": "left"}),
+            )
+        children = [el for dim in dims for el in _create_row(dim)]
+
+        # Add a horizontal ruler and show the selector if available
+        selector_columns = data.attrs["selector_columns"]
+        first_selector = next((i for i, dim in enumerate(dims) if dim in selector_columns), None)
+        if first_selector:  # Don't show if first
+            divider = [Div(style={
+                "border": "none",
+                "height": "1px",
+                "background-color": "#ccc",
+                "margin": "4px 0",
+                "grid-column": "span 2",
+            })]
+        else:
+            divider = ()
+
+
+        if first_selector is not None and data.attrs.get("selector") and self.selector_in_hovertool:
+            selector_row = (
+                Span(children=["Selector:"], style={"color": "#26aae1", "font-weight": "bold", "text_align": "right"}),
+                Span(children=[data.attrs["selector"]], style={"font-weight": "bold", "text_align": "left"}),
+             )
+        else:
+            selector_row = ()
+
+        first_selector = first_selector or 0
+        children = [
+            *children[:first_selector * 2],
+            *divider,
+            *selector_row,
+            *children[first_selector * 2:],
+        ]
+
+        style = Styles(display="grid", grid_template_columns="auto auto", column_gap="10px")
+        grid = Div(children=children, style=style)
+        hover.tooltips = grid
+        hover.callback = CustomJS(
+            args={"position": hover_model},
+            code="export default ({position}, _, {geometry: {x, y}}) => {position.xy = [x, y]}",
+        )
+
+        def on_change(attr, old, new):
+            if np.isinf(new).all():
+                return
+            if is_datetime[0]:
+                new[0] = _EPOCH + np.timedelta64(int(new[0] * 1e6), "ns")
+            if is_datetime[1]:
+                new[1] = _EPOCH + np.timedelta64(int(new[1] * 1e6), "ns")
+            try:
+                data_sel = self._hover_data.sel(
+                    **dict(zip(self._hover_data.coords, new, strict=True)),
+                    method="nearest"
+                ).to_dict()
+            except KeyError:
+                # Can happen when a coord is empty, e.g. xlim=(0, 0)
+                return
+            data_coords = {dim: data_sel['coords'][dim]['data'] for dim in coords}
+            data_vars = {dim: data_sel['data_vars'][dim]['data'] for dim in vars}
+            with hold(self.document):
+                hover_model.update(data={**data_coords, **data_vars})
+                if self.comm:  # Jupyter Notebook
+                    self.push()
+
+        hover_model.on_change("xy", on_change)
+
+        return tools
+
+
+class RasterPlot(ServerHoverMixin, ColorbarPlot):
 
     clipping_colors = param.Dict(default={'NaN': 'transparent'})
 
@@ -131,7 +300,7 @@ class RasterPlot(ColorbarPlot):
         return (data, mapping, style)
 
 
-class RGBPlot(LegendPlot):
+class RGBPlot(ServerHoverMixin, LegendPlot):
 
     padding = param.ClassSelector(default=0, class_=(int, float, tuple))
 
@@ -268,7 +437,7 @@ class ImageStackPlot(RasterPlot):
                     "The supplied cmap dictionary must have the same "
                     f"value dimensions as the element. Missing: '{missing_str}'"
                 )
-            keys, values = zip(*dict_cmap.items())
+            keys, values = zip(*dict_cmap.items(), strict=None)
             style["cmap"] = list(values)
             indices = [keys.index(vd.name) for vd in vdims]
 
@@ -297,6 +466,8 @@ class ImageStackPlot(RasterPlot):
             else element.dimension_values(vd, flat=False).transpose()
             for vd in element.vdims
         ])
+        if 0 in img.shape[:2]:  # Means we don't have any data
+            img = np.array([[[np.nan]]])
         # Ensure axis inversions are handled correctly
         l, b, r, t = element.bounds.lbrt()
         if self.invert_axes:
@@ -391,7 +562,7 @@ class QuadMeshPlot(ColorbarPlot):
             XS, YS = [], []
             mask = []
             xc, yc = [], []
-            for xs, ys, zval in zip(X, Y, zvals):
+            for xs, ys, zval in zip(X, Y, zvals, strict=None):
                 xs, ys = xs[:-1], ys[:-1]
                 if isfinite(zval) and all(isfinite(xs)) and all(isfinite(ys)):
                     XS.append(list(xs))
@@ -430,14 +601,14 @@ class QuadMeshPlot(ColorbarPlot):
         return data, mapping, style
 
     def _collect_hover_data(self, element, mask=(), irregular=False):
-        """
-        Returns a dict mapping hover dimension names to flattened arrays.
+        """Returns a dict mapping hover dimension names to flattened arrays.
 
         Note that `Quad` glyphs are used when given 1-D coords but `Patches` are
         used for "irregular" 2-D coords, and Bokeh inserts data into these glyphs
         in the opposite order such that the relationship b/w the `invert_axes`
         parameter and the need to transpose the arrays before flattening is
         reversed.
+
         """
         transpose = self.invert_axes if irregular else not self.invert_axes
 
@@ -445,14 +616,14 @@ class QuadMeshPlot(ColorbarPlot):
         hover_vals = [element.dimension_values(hover_dim, flat=False)
                       for hover_dim in hover_dims]
         hover_data = {}
-        for hdim, hvals in zip(hover_dims, hover_vals):
+        for hdim, hvals in zip(hover_dims, hover_vals, strict=None):
             hdat = hvals.T.flatten() if transpose else hvals.flatten()
             hover_data[dimension_sanitizer(hdim.name)] = hdat[mask]
         return hover_data
 
     def _init_glyph(self, plot, mapping, properties):
-        """
-        Returns a Bokeh glyph object.
+        """Returns a Bokeh glyph object.
+
         """
         properties = mpl_to_bokeh(properties)
         properties = dict(properties, **mapping)
