@@ -1,7 +1,7 @@
-"""
-The streams module defines the streams API that allows visualizations to
+"""The streams module defines the streams API that allows visualizations to
 generate and respond to events, originating either in Python on the
 server-side or in Javascript in the Jupyter notebook (client-side).
+
 """
 
 import weakref
@@ -11,16 +11,27 @@ from functools import partial
 from itertools import groupby
 from numbers import Number
 from types import FunctionType
+from typing import TYPE_CHECKING
 
 import numpy as np
-import pandas as pd
 import param
 
 from .core import util
 from .core.ndmapping import UniformNdMapping
+from .util.warnings import deprecated
+
+if TYPE_CHECKING:
+    import pandas as pd
+else:
+    pd = util.dependencies._LazyModule("pandas", bool_use_sys_modules=True)
+
 
 # Types supported by Pointer derived streams
-pointer_types = (Number, str, tuple, *util.datetime_types)
+@util.types.gen_types
+def pointer_types():
+    yield from (Number, str, tuple)
+    yield from util.datetime_types
+
 
 POPUP_POSITIONS = [
     "top_right",
@@ -38,12 +49,12 @@ class _SkipTrigger: pass
 
 @contextmanager
 def triggering_streams(streams):
-    """
-    Temporarily declares the streams as being in a triggered state.
+    """Temporarily declares the streams as being in a triggered state.
     Needed by DynamicMap to determine whether to memoize on a Callable,
     i.e. if a stream has memoization disabled and is in triggered state
     Callable should disable lookup in the memoization cache. This is
     done by the dynamicmap_memoization context manager.
+
     """
     for stream in streams:
         stream._triggering = True
@@ -55,20 +66,28 @@ def triggering_streams(streams):
 
 
 def streams_list_from_dict(streams):
-    "Converts a streams dictionary into a streams list"
-    params = {}
+    """Converts a streams dictionary into a streams list
+
+    """
+    params, refs = {}, {}
     for k, v in streams.items():
         v = param.parameterized.transform_reference(v)
         if isinstance(v, param.Parameter) and v.owner is not None:
             params[k] = v
+            continue
+        deps = param.parameterized.resolve_ref(v, recursive=True)
+        if deps:
+            refs[k] = v
         else:
-            raise TypeError(f'Cannot handle value {v!r} in streams dictionary')
-    return Params.from_params(params)
+            raise TypeError(f'Cannot handle {k!r} value {v!r} in streams dictionary')
+    streams = Params.from_params(params)
+    if not refs:
+        return streams
+    return [*streams, ParamRefs(refs=refs, recursive=True)]
 
 
 class Stream(param.Parameterized):
-    """
-    A Stream is simply a parameterized object with parameters that
+    """A Stream is simply a parameterized object with parameters that
     change over time in response to update events and may trigger
     downstream events on its subscribers. The Stream parameters can be
     updated using the update method, which will optionally trigger the
@@ -96,6 +115,7 @@ class Stream(param.Parameterized):
     transform and reset method to preprocess parameters before they
     are passed to subscribers and reset them using custom logic
     respectively.
+
     """
 
     # Mapping from a source to a list of streams
@@ -110,8 +130,7 @@ class Stream(param.Parameterized):
 
     @classmethod
     def define(cls, name, **kwargs):
-        """
-        Utility to quickly and easily declare Stream classes. Designed
+        """Utility to quickly and easily declare Stream classes. Designed
         for interactive use such as notebooks and shouldn't replace
         parameterized class definitions in source code that is imported.
 
@@ -121,6 +140,7 @@ class Stream(param.Parameterized):
         type is inferred and declared, using the value as the default.
 
         Supported types: bool, int, float, str, dict, tuple and list
+
         """
         params = {'name': param.String(default=name)}
         for k, v in kwargs.items():
@@ -152,13 +172,13 @@ class Stream(param.Parameterized):
 
     @classmethod
     def trigger(cls, streams):
-        """
-        Given a list of streams, collect all the stream parameters into
+        """Given a list of streams, collect all the stream parameters into
         a dictionary and pass it to the union set of subscribers.
 
         Passing multiple streams at once to trigger can be useful when a
         subscriber may be set multiple times across streams but only
         needs to be called once.
+
         """
         # Union of stream contents
         items = [stream.contents.items() for stream in set(streams)]
@@ -199,14 +219,16 @@ class Stream(param.Parameterized):
 
 
     def _on_trigger(self):
-        """Called when a stream has been triggered"""
+        """Called when a stream has been triggered
+
+        """
 
 
     @classmethod
     def _process_streams(cls, streams):
-        """
-        Processes a list of streams promoting Parameterized objects and
+        """Processes a list of streams promoting Parameterized objects and
         methods to Param based streams.
+
         """
         parameterizeds = defaultdict(set)
         valid, invalid = [], []
@@ -255,8 +277,7 @@ class Stream(param.Parameterized):
 
     def __init__(self, rename=None, source=None, subscribers=None, linked=False,
                  transient=False, **params):
-        """
-        The rename argument allows multiple streams with similar event
+        """The rename argument allows multiple streams with similar event
         state to be used by remapping parameter names.
 
         Source is an optional argument specifying the HoloViews
@@ -265,8 +286,8 @@ class Stream(param.Parameterized):
 
         Some streams are configured to automatically link to the source
         plot, to disable this set linked=False
-        """
 
+        """
         # Source is stored as a weakref to allow it to be garbage collected
         if subscribers is None:
             subscribers = []
@@ -298,24 +319,28 @@ class Stream(param.Parameterized):
                 self.registry[source] = [self]
 
     def clone(self):
-        """Return new stream with identical properties and no subscribers"""
+        """Return new stream with identical properties and no subscribers
+
+        """
         return type(self)(**self.contents)
 
     @property
     def subscribers(self):
-        """Property returning the subscriber list"""
+        """Property returning the subscriber list
+
+        """
         return [s for p, s in sorted(self._subscribers, key=lambda x: x[0])]
 
 
     def clear(self, policy='all'):
-        """
-        Clear all subscribers registered to this stream.
+        """Clear all subscribers registered to this stream.
 
         The default policy of 'all' clears all subscribers. If policy is
         set to 'user', only subscribers defined by the user are cleared
         (precedence between zero and one). A policy of 'internal' clears
         subscribers with precedence greater than unity used internally
         by HoloViews.
+
         """
         policies = ['all', 'user', 'internal']
         if policy not in policies:
@@ -330,8 +355,8 @@ class Stream(param.Parameterized):
 
 
     def reset(self):
-        """
-        Resets stream parameters to their defaults.
+        """Resets stream parameters to their defaults.
+
         """
         with util.disable_constant(self):
             for k, p in self.param.objects('existing').items():
@@ -340,8 +365,7 @@ class Stream(param.Parameterized):
 
 
     def add_subscriber(self, subscriber, precedence=0):
-        """
-        Register a callable subscriber to this stream which will be
+        """Register a callable subscriber to this stream which will be
         invoked either when event is called or when this stream is
         passed to the trigger classmethod.
 
@@ -350,6 +374,7 @@ class Stream(param.Parameterized):
         between zero and one while HoloViews itself reserves the use of
         higher precedence values. Subscribers with high precedence are
         invoked later than ones with low precedence.
+
         """
         if not callable(subscriber):
             raise TypeError('Subscriber must be a callable.')
@@ -368,11 +393,11 @@ class Stream(param.Parameterized):
 
 
     def rename(self, **mapping):
-        """
-        The rename method allows stream parameters to be allocated to
+        """The rename method allows stream parameters to be allocated to
         new names to avoid clashes with other stream parameters of the
         same name. Returns a new clone of the stream instance with the
         specified name mapping.
+
         """
         params = {k: v for k, v in self.param.values().items() if k != 'name'}
         return self.__class__(rename=mapping,
@@ -405,10 +430,10 @@ class Stream(param.Parameterized):
 
 
     def transform(self):
-        """
-        Method that can be overwritten by subclasses to process the
+        """Method that can be overwritten by subclasses to process the
         parameter values before renaming is applied. Returns a
         dictionary of transformed parameters.
+
         """
         return {}
 
@@ -421,38 +446,38 @@ class Stream(param.Parameterized):
 
     @property
     def hashkey(self):
-        """
-        The object the memoization hash is computed from. By default
+        """The object the memoization hash is computed from. By default
         returns the stream contents but can be overridden to provide
         a custom hash key.
+
         """
         return self.contents
 
 
     def _set_stream_parameters(self, **kwargs):
-        """
-        Sets the stream parameters which are expected to be declared
+        """Sets the stream parameters which are expected to be declared
         constant.
+
         """
         with util.disable_constant(self):
             self.param.update(**kwargs)
 
     def event(self, **kwargs):
-        """
-        Update the stream parameters and trigger an event.
+        """Update the stream parameters and trigger an event.
+
         """
         skip = self.update(**kwargs)
         if skip is not _SkipTrigger:
             self.trigger([self])
 
     def update(self, **kwargs):
-        """
-        The update method updates the stream parameters (without any
+        """The update method updates the stream parameters (without any
         renaming applied) in response to some event. If the stream has a
         custom transform method, this is applied to transform the
         parameter values accordingly.
 
         To update and trigger, use the event method.
+
         """
         self._set_stream_parameters(**kwargs)
         transformed = self.transform()
@@ -475,9 +500,9 @@ class Stream(param.Parameterized):
 
 
 class Counter(Stream):
-    """
-    Simple stream that automatically increments an integer counter
+    """Simple stream that automatically increments an integer counter
     parameter every time it is updated.
+
     """
 
     counter = param.Integer(default=0, constant=True, bounds=(0, None))
@@ -487,10 +512,10 @@ class Counter(Stream):
 
 
 class Pipe(Stream):
-    """
-    A Stream used to pipe arbitrary data to a callback.
+    """A Stream used to pipe arbitrary data to a callback.
     Unlike other streams memoization can be disabled for a
     Pipe stream (and is disabled by default).
+
     """
 
     data = param.Parameter(default=None, constant=True, doc="""
@@ -501,9 +526,9 @@ class Pipe(Stream):
         self._memoize_counter = 0
 
     def send(self, data):
-        """
-        A convenience method to send an event with data without
+        """A convenience method to send an event with data without
         supplying a keyword.
+
         """
         self.event(data=data)
 
@@ -516,18 +541,13 @@ class Pipe(Stream):
 
 
 class Buffer(Pipe):
-    """
-    Buffer allows streaming and accumulating incoming chunks of rows
+    """Buffer allows streaming and accumulating incoming chunks of rows
     from tabular datasets. The data may be in the form of a pandas
     DataFrame, 2D arrays of rows and columns or dictionaries of column
     arrays. Buffer will accumulate the last N rows, where N is defined
     by the specified ``length``. The accumulated data is then made
     available via the ``data`` parameter.
 
-    A Buffer may also be instantiated with a streamz.StreamingDataFrame
-    or a streamz.StreamingSeries, it will automatically subscribe to
-    events emitted by a streamz object.
-
     When streaming a DataFrame will reset the DataFrame index by
     default making it available to HoloViews elements as dimensions,
     this may be disabled by setting index=False.
@@ -536,13 +556,14 @@ class Buffer(Pipe):
     subscribed to this stream will update the axis ranges when an
     update is pushed. This makes it possible to control whether zooming
     is allowed while streaming.
+
     """
 
     data = param.Parameter(default=None, constant=True, doc="""
         Arbitrary data being streamed to a DynamicMap callback.""")
 
     def __init__(self, data, length=1000, index=True, following=True, **params):
-        if isinstance(data, pd.DataFrame):
+        if pd and isinstance(data, pd.DataFrame):
             example = data
         elif isinstance(data, np.ndarray):
             if data.ndim != 2:
@@ -567,6 +588,10 @@ class Buffer(Pipe):
                     loaded = True
                 except ImportError:
                     loaded = False
+            if loaded:
+                # NOTE: there could still be some code in these classes which handles
+                # the streaming interface.
+                deprecated("1.23.0", "Buffer's streamz interface")
             if not loaded or not isinstance(data, (StreamingDataFrame, StreamingSeries)):
                 raise ValueError("Buffer must be initialized with pandas DataFrame, "
                                  "streamz.StreamingDataFrame or streamz.StreamingSeries.")
@@ -586,7 +611,9 @@ class Buffer(Pipe):
 
 
     def verify(self, x):
-        """ Verify consistency of dataframes that pass through this stream """
+        """Verify consistency of dataframes that pass through this stream
+
+        """
         if type(x) != type(self.data):  # noqa: E721
             raise TypeError(f"Input expected to be of type {type(self.data).__name__}, got {type(x).__name__}.")
         elif isinstance(x, np.ndarray):
@@ -595,7 +622,7 @@ class Buffer(Pipe):
             elif x.shape[1] != self.data.shape[1]:
                 raise ValueError(f"Streamed array data expected to have {self.data.shape[1]} columns, "
                                  f"got {x.shape[1]}.")
-        elif isinstance(x, pd.DataFrame) and list(x.columns) != list(self.data.columns):
+        elif pd and isinstance(x, pd.DataFrame) and list(x.columns) != list(self.data.columns):
             raise IndexError(f"Input expected to have columns {list(self.data.columns)}, got {list(x.columns)}")
         elif isinstance(x, dict):
             if any(c not in x for c in self.data):
@@ -606,10 +633,12 @@ class Buffer(Pipe):
 
 
     def clear(self):
-        "Clears the data in the stream"
+        """Clears the data in the stream
+
+        """
         if isinstance(self.data, np.ndarray):
             data = self.data[:, :0]
-        elif isinstance(self.data, pd.DataFrame):
+        elif pd and isinstance(self.data, pd.DataFrame):
             data = self.data.iloc[:0]
         elif isinstance(self.data, dict):
             data = {k: v[:0] for k, v in self.data.items()}
@@ -619,9 +648,9 @@ class Buffer(Pipe):
 
 
     def _concat(self, data):
-        """
-        Concatenate and slice the accepted data types to the defined
+        """Concatenate and slice the accepted data types to the defined
         length.
+
         """
         if isinstance(data, np.ndarray):
             data_length = len(data)
@@ -632,7 +661,7 @@ class Buffer(Pipe):
                 data = np.concatenate([prev_chunk, data])
             elif data_length > self.length:
                 data = data[-self.length:]
-        elif isinstance(data, pd.DataFrame):
+        elif pd and isinstance(data, pd.DataFrame):
             data_length = len(data)
             if not self.length:
                 data = pd.concat([self.data, data])
@@ -660,8 +689,8 @@ class Buffer(Pipe):
 
 
     def update(self, **kwargs):
-        """
-        Overrides update to concatenate streamed data up to defined length.
+        """Overrides update to concatenate streamed data up to defined length.
+
         """
         data = kwargs.get('data')
         if data is not None:
@@ -676,11 +705,74 @@ class Buffer(Pipe):
         return {'hash': (self._count, self._memoize_counter)}
 
 
+class ParamRefs(Stream):
+    """
+    ParamRefs accepts a dictionary of parameter references, watching
+    their dependencies and returning their resolved values.
+    """
+
+    recursive = param.Boolean(default=False, constant=True, doc="Whether references should be resolved recursively.")
+
+    refs = param.Dict(doc="Dictionary of references", constant=True)
+
+    def __init__(self, refs=None, watch=True, **params):
+        super().__init__(refs=refs or {}, **params)
+        self._memoize_counter = 0
+        self._watchers = []
+        if not watch:
+            return
+
+        # Collect all dependencies of the provided references
+        parameters = []
+        for ref in self.refs.values():
+            prefs = param.parameterized.resolve_ref(ref, recursive=self.recursive)
+            parameters += [p for p in prefs if p not in parameters]
+
+        # Subscribe to parameters
+        keyfn = lambda x: id(x.owner)
+        for _, group in groupby(sorted(parameters, key=keyfn), key=keyfn):
+            group = list(group)
+            watcher = group[0].owner.param.watch(self._watcher, [p.name for p in group])
+            self._watchers.append(watcher)
+
+    def unwatch(self):
+        """Stop watching parameters."""
+        for watcher in self._watchers:
+            watcher.inst.param.unwatch(watcher)
+        self._watchers.clear()
+
+    def _watcher(self, *events):
+        try:
+            self._events = list(events)
+            self.trigger([self])
+        finally:
+            self._events = []
+
+    def _on_trigger(self):
+        if any(e.type == 'triggered' for e in self._events):
+            self._memoize_counter += 1
+
+    @property
+    def contents(self):
+        return {
+            p: param.parameterized.resolve_value(ref, recursive=self.recursive)
+            for p, ref in self.refs.items()
+        }
+
+    @property
+    def hashkey(self):
+        hashkey = dict(self.contents)
+        hashkey['_memoize_key'] = self._memoize_counter
+        return hashkey
+
+    def reset(self):
+        pass
+
 
 class Params(Stream):
-    """
-    A Stream that watches the changes in the parameters of the supplied
+    """A Stream that watches the changes in the parameters of the supplied
     Parameterized objects and triggers when they change.
+
     """
 
     parameterized = param.ClassSelector(class_=(param.Parameterized,
@@ -736,11 +828,14 @@ class Params(Stream):
     def from_params(cls, params, **kwargs):
         """Returns Params streams given a dictionary of parameters
 
-        Args:
-            params (dict): Dictionary of parameters
+        Parameters
+        ----------
+        params : dict
+            Dictionary of parameters
 
-        Returns:
-            List of Params streams
+        Returns
+        -------
+        List of Params streams
         """
         key_fn = lambda x: id(x[1].owner)
         streams = []
@@ -819,10 +914,10 @@ class Params(Stream):
 
 
 class ParamMethod(Params):
-    """
-    A Stream that watches the parameter dependencies on a method of
+    """A Stream that watches the parameter dependencies on a method of
     a parameterized class and triggers when one of the parameters
     change.
+
     """
 
     parameterized = param.ClassSelector(class_=(param.Parameterized,
@@ -847,12 +942,13 @@ class ParamMethod(Params):
 
 
 class Derived(Stream):
-    """
-    A Stream that watches the parameters of one or more input streams and produces
+    """A Stream that watches the parameters of one or more input streams and produces
     a result that is a pure function of the input stream values.
 
     If exclusive=True, then all streams except the most recently updated are cleared.
+
     """
+
     def __init__(self, input_streams, exclusive=False, **params):
         super().__init__(**params)
         self.input_streams = []
@@ -862,8 +958,8 @@ class Derived(Stream):
         self.update()
 
     def _register_streams(self, streams):
-        """
-        Register callbacks to watch for changes to input streams
+        """Register callbacks to watch for changes to input streams
+
         """
         for stream in streams:
             self._register_stream(stream)
@@ -891,8 +987,8 @@ class Derived(Stream):
         self.input_streams.append(stream)
 
     def _unregister_input_streams(self):
-        """
-        Unregister callbacks on input streams and clear input streams list
+        """Unregister callbacks on input streams and clear input streams list
+
         """
         for stream in self.input_streams:
             stream.source = None
@@ -900,20 +996,20 @@ class Derived(Stream):
         self.input_streams.clear()
 
     def append_input_stream(self, stream):
-        """
-        Add a new input stream
+        """Add a new input stream
+
         """
         self._register_stream(stream)
 
     @property
     def constants(self):
-        """
-        Dict of constants for this instance that should be passed to transform_function
+        """Dict of constants for this instance that should be passed to transform_function
 
         Constant values must not change in response to changes in the values of the
         input streams. They may, however, change in response to other stream property
         updates. For example, these values may change if the Stream's source element
         changes
+
         """
         return {}
 
@@ -923,18 +1019,20 @@ class Derived(Stream):
 
     @classmethod
     def transform_function(cls, stream_values, constants):
-        """
-        Pure function that transforms input stream param values into the param values
+        """Pure function that transforms input stream param values into the param values
         of this Derived stream.
 
-        Args:
-            stream_values: list of dict
-                Current values of the stream params for each input_stream
-            constants: dict
-                Constants as returned by the constants property of an instance of this
-                stream type.
+        Parameters
+        ----------
+        stream_values : list of dict
+            Current values of the stream params for each input_stream
+        constants : dict
+            Constants as returned by the constants property of an instance of this
+            stream type.
 
-        Returns: dict
+        Returns
+        -------
+        dict
             dict of new Stream values where the keys match this stream's params
         """
         raise NotImplementedError
@@ -944,9 +1042,10 @@ class Derived(Stream):
 
 
 class History(Stream):
+    """A Stream that maintains a history of the values of a single input stream
+
     """
-    A Stream that maintains a history of the values of a single input stream
-    """
+
     values = param.List(constant=True, doc="""
         List containing the historical values of the input stream""")
 
@@ -965,8 +1064,8 @@ class History(Stream):
         del self.values[:]
 
     def _register_input_stream(self):
-        """
-        Register callback on input_stream to watch for changes
+        """Register callback on input_stream to watch for changes
+
         """
         def perform_update(**kwargs):
             self.values.append(kwargs)
@@ -1260,10 +1359,10 @@ class CrossFilterSet(Derived):
 
 
 class LinkedStream(Stream):
-    """
-    A LinkedStream indicates is automatically linked to plot interactions
+    """A LinkedStream indicates is automatically linked to plot interactions
     on a backend via a Renderer. Not all backends may support dynamically
     supplying stream data.
+
     """
 
     def __init__(self, linked=True, popup=None, popup_position="top_right", popup_anchor=None, **params):
@@ -1280,13 +1379,13 @@ class LinkedStream(Stream):
 
 
 class PointerX(LinkedStream):
-    """
-    A pointer position along the x-axis in data coordinates which may be
+    """A pointer position along the x-axis in data coordinates which may be
     a numeric or categorical dimension.
 
     With the appropriate plotting backend, this corresponds to the
     position of the mouse/trackpad cursor. If the pointer is outside the
     plot bounds, the position is set to None.
+
     """
 
     x = param.ClassSelector(class_=pointer_types, default=None,
@@ -1295,15 +1394,14 @@ class PointerX(LinkedStream):
 
 
 class PointerY(LinkedStream):
-    """
-    A pointer position along the y-axis in data coordinates which may be
+    """A pointer position along the y-axis in data coordinates which may be
     a numeric or categorical dimension.
 
     With the appropriate plotting backend, this corresponds to the
     position of the mouse/trackpad pointer. If the pointer is outside
     the plot bounds, the position is set to None.
-    """
 
+    """
 
     y = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
@@ -1311,13 +1409,13 @@ class PointerY(LinkedStream):
 
 
 class PointerXY(LinkedStream):
-    """
-    A pointer position along the x- and y-axes in data coordinates which
+    """A pointer position along the x- and y-axes in data coordinates which
     may numeric or categorical dimensions.
 
     With the appropriate plotting backend, this corresponds to the
     position of the mouse/trackpad pointer. If the pointer is outside
     the plot bounds, the position values are set to None.
+
     """
 
     x = param.ClassSelector(class_=pointer_types, default=None,
@@ -1330,10 +1428,11 @@ class PointerXY(LinkedStream):
 
 
 class Draw(PointerXY):
-    """
-    A series of updating x/y-positions when drawing, together with the
+    """A series of updating x/y-positions when drawing, together with the
     current stroke count
+
     """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1347,8 +1446,8 @@ class Draw(PointerXY):
        stroke is started.""")
 
 class SingleTap(PointerXY):
-    """
-    The x/y-position of a single tap or click in data coordinates.
+    """The x/y-position of a single tap or click in data coordinates.
+
     """
 
     x = param.ClassSelector(class_=pointer_types, default=None,
@@ -1360,9 +1459,10 @@ class SingleTap(PointerXY):
            Pointer position along the y-axis in data coordinates""")
 
 class Tap(PointerXY):
+    """The x/y-position of a tap or click in data coordinates.
+
     """
-    The x/y-position of a tap or click in data coordinates.
-    """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1373,8 +1473,8 @@ class Tap(PointerXY):
 
 
 class MultiAxisTap(LinkedStream):
-    """
-    The x/y-positions of a tap or click in data coordinates.
+    """The x/y-positions of a tap or click in data coordinates.
+
     """
 
     xs = param.Dict(default=None, constant=True, doc="""
@@ -1385,9 +1485,10 @@ class MultiAxisTap(LinkedStream):
 
 
 class DoubleTap(PointerXY):
+    """The x/y-position of a double-tap or -click in data coordinates.
+
     """
-    The x/y-position of a double-tap or -click in data coordinates.
-    """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1397,9 +1498,10 @@ class DoubleTap(PointerXY):
            Pointer position along the y-axis in data coordinates""")
 
 class PressUp(PointerXY):
+    """The x/y position of a mouse pressup event in data coordinates.
+
     """
-    The x/y position of a mouse pressup event in data coordinates.
-    """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1410,7 +1512,9 @@ class PressUp(PointerXY):
 
 class PanEnd(PointerXY):
     """The x/y position of a the end of a pan event in data coordinates.
+
     """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1420,10 +1524,11 @@ class PanEnd(PointerXY):
            Pointer position along the y-axis in data coordinates""")
 
 class MouseEnter(PointerXY):
-    """
-    The x/y-position where the mouse/cursor entered the plot area
+    """The x/y-position where the mouse/cursor entered the plot area
     in data coordinates.
+
     """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1434,10 +1539,11 @@ class MouseEnter(PointerXY):
 
 
 class MouseLeave(PointerXY):
-    """
-    The x/y-position where the mouse/cursor entered the plot area
+    """The x/y-position where the mouse/cursor entered the plot area
     in data coordinates.
+
     """
+
     x = param.ClassSelector(class_=pointer_types, default=None,
                             constant=True, doc="""
            Pointer position along the x-axis in data coordinates""")
@@ -1448,8 +1554,8 @@ class MouseLeave(PointerXY):
 
 
 class PlotSize(LinkedStream):
-    """
-    Returns the dimensions of a plot once it has been displayed.
+    """Returns the dimensions of a plot once it has been displayed.
+
     """
 
     width = param.Integer(default=None, constant=True, doc="The width of the plot in pixels")
@@ -1475,8 +1581,8 @@ class SelectMode(LinkedStream):
 
 
 class RangeXY(LinkedStream):
-    """
-    Axis ranges along x- and y-axis in data coordinates.
+    """Axis ranges along x- and y-axis in data coordinates.
+
     """
 
     x_range = param.Tuple(default=None, length=2, constant=True, doc="""
@@ -1487,8 +1593,8 @@ class RangeXY(LinkedStream):
 
 
 class RangeX(LinkedStream):
-    """
-    Axis range along x-axis in data coordinates.
+    """Axis range along x-axis in data coordinates.
+
     """
 
     x_range = param.Tuple(default=None, length=2, constant=True, doc="""
@@ -1500,8 +1606,8 @@ class RangeX(LinkedStream):
 
 
 class RangeY(LinkedStream):
-    """
-    Axis range along y-axis in data coordinates.
+    """Axis range along y-axis in data coordinates.
+
     """
 
     y_range = param.Tuple(default=None, length=2, constant=True, doc="""
@@ -1513,9 +1619,9 @@ class RangeY(LinkedStream):
 
 
 class BoundsXY(LinkedStream):
-    """
-    A stream representing the bounds of a box selection as an
+    """A stream representing the bounds of a box selection as an
     tuple of the left, bottom, right and top coordinates.
+
     """
 
     bounds = param.Tuple(default=None, constant=True, length=4,
@@ -1524,9 +1630,9 @@ class BoundsXY(LinkedStream):
 
 
 class Lasso(LinkedStream):
-    """
-    A stream representing a lasso selection in 2D space as a two-column
+    """A stream representing a lasso selection in 2D space as a two-column
     array of coordinates.
+
     """
 
     geometry = param.Array(constant=True, doc="""
@@ -1534,10 +1640,10 @@ class Lasso(LinkedStream):
 
 
 class SelectionXY(BoundsXY):
-    """
-    A stream representing the selection along the x-axis and y-axis.
+    """A stream representing the selection along the x-axis and y-axis.
     Unlike a BoundsXY stream, this stream returns range or categorical
     selections.
+
     """
 
     bounds = param.Tuple(default=None, constant=True, length=4,
@@ -1556,9 +1662,9 @@ class SelectionXY(BoundsXY):
 
 
 class BoundsX(LinkedStream):
-    """
-    A stream representing the bounds of a box selection as an
+    """A stream representing the bounds of a box selection as an
     tuple of the left and right coordinates.
+
     """
 
     boundsx = param.Tuple(default=None, constant=True, length=2,
@@ -1567,9 +1673,9 @@ class BoundsX(LinkedStream):
 
 
 class BoundsY(LinkedStream):
-    """
-    A stream representing the bounds of a box selection as an
+    """A stream representing the bounds of a box selection as an
     tuple of the bottom and top coordinates.
+
     """
 
     boundsy = param.Tuple(default=None, constant=True, length=2,
@@ -1578,8 +1684,8 @@ class BoundsY(LinkedStream):
 
 
 class Selection1D(LinkedStream):
-    """
-    A stream representing a 1D selection of objects by their index.
+    """A stream representing a 1D selection of objects by their index.
+
     """
 
     index = param.List(default=[], allow_None=True, constant=True, doc="""
@@ -1587,8 +1693,8 @@ class Selection1D(LinkedStream):
 
 
 class PlotReset(LinkedStream):
-    """
-    A stream signalling when a plot reset event has been triggered.
+    """A stream signalling when a plot reset event has been triggered.
+
     """
 
     resetting = param.Boolean(default=False, constant=True, doc="""
@@ -1599,8 +1705,8 @@ class PlotReset(LinkedStream):
 
 
 class CDSStream(LinkedStream):
-    """
-    A Stream that syncs a bokeh ColumnDataSource with python.
+    """A Stream that syncs a bokeh ColumnDataSource with python.
+
     """
 
     data = param.Dict(constant=True, doc="""
@@ -1611,27 +1717,26 @@ class CDSStream(LinkedStream):
 
 
 class PointDraw(CDSStream):
-    """
-    Attaches a PointDrawTool and syncs the datasource.
+    """Attaches a PointDrawTool and syncs the datasource.
 
-    add: boolean
+    add : boolean
         Whether to allow adding new Points
 
-    drag: boolean
+    drag : boolean
         Whether to enable dragging of Points
 
-    empty_value: int/float/string/None
+    empty_value : int/float/string/None
         The value to insert on non-position columns when adding a new polygon
 
-    num_objects: int
+    num_objects : int
         The number of polygons that can be drawn before overwriting
         the oldest polygon.
 
-    styles: dict
+    styles : dict
         A dictionary specifying lists of styles to cycle over whenever
         a new Point glyph is drawn.
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
     """
 
@@ -1671,13 +1776,12 @@ class PointDraw(CDSStream):
 
 
 class CurveEdit(PointDraw):
-    """
-    Attaches a PointDraw to the plot which allows editing the Curve when selected.
+    """Attaches a PointDraw to the plot which allows editing the Curve when selected.
 
-    style: dict
+    style : dict
         A dictionary specifying the style of the vertices.
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
     """
 
@@ -1697,30 +1801,29 @@ class CurveEdit(PointDraw):
 
 
 class PolyDraw(CDSStream):
-    """
-    Attaches a PolyDrawTool and syncs the datasource.
+    """Attaches a PolyDrawTool and syncs the datasource.
 
-    drag: boolean
+    drag : boolean
         Whether to enable dragging of polygons and paths
 
-    empty_value: int/float/string/None
+    empty_value : int/float/string/None
         The value to insert on non-position columns when adding a new polygon
 
-    num_objects: int
+    num_objects : int
         The number of polygons that can be drawn before overwriting
         the oldest polygon.
 
-    show_vertices: boolean
+    show_vertices : boolean
         Whether to show the vertices when a polygon is selected
 
-    styles: dict
+    styles : dict
         A dictionary specifying lists of styles to cycle over whenever
         a new Poly glyph is drawn.
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
 
-    vertex_style: dict
+    vertex_style : dict
         A dictionary specifying the style options for the vertices.
         The usual bokeh style options apply, e.g. fill_color,
         line_alpha, size, etc.
@@ -1771,21 +1874,20 @@ class PolyDraw(CDSStream):
 
 
 class FreehandDraw(CDSStream):
-    """
-    Attaches a FreehandDrawTool and syncs the datasource.
+    """Attaches a FreehandDrawTool and syncs the datasource.
 
-    empty_value: int/float/string/None
+    empty_value : int/float/string/None
         The value to insert on non-position columns when adding a new polygon
 
-    num_objects: int
+    num_objects : int
         The number of polygons that can be drawn before overwriting
         the oldest polygon.
 
-    styles: dict
+    styles : dict
         A dictionary specifying lists of styles to cycle over whenever
         a new freehand glyph is drawn.
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
     """
 
@@ -1827,21 +1929,20 @@ class FreehandDraw(CDSStream):
 
 
 class BoxEdit(CDSStream):
-    """
-    Attaches a BoxEditTool and syncs the datasource.
+    """Attaches a BoxEditTool and syncs the datasource.
 
-    empty_value: int/float/string/None
+    empty_value : int/float/string/None
         The value to insert on non-position columns when adding a new box
 
-    num_objects: int
+    num_objects : int
         The number of boxes that can be drawn before overwriting the
         oldest drawn box.
 
-    styles: dict
+    styles : dict
         A dictionary specifying lists of styles to cycle over whenever
         a new box glyph is drawn.
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
     """
 
@@ -1875,7 +1976,7 @@ class BoxEdit(CDSStream):
             data = tuple(data[d] for d in dims)
             return source.clone(data, id=None)
         paths = []
-        for i, (x0, x1, y0, y1) in enumerate(zip(data['x0'], data['x1'], data['y0'], data['y1'])):
+        for i, (x0, x1, y0, y1) in enumerate(zip(data['x0'], data['x1'], data['y0'], data['y1'], strict=None)):
             xs = [x0, x0, x1, x1]
             ys = [y0, y1, y1, y0]
             if isinstance(source, Polygons):
@@ -1894,16 +1995,15 @@ class BoxEdit(CDSStream):
 
 
 class PolyEdit(PolyDraw):
-    """
-    Attaches a PolyEditTool and syncs the datasource.
+    """Attaches a PolyEditTool and syncs the datasource.
 
-    shared: boolean
+    shared : boolean
         Whether PolyEditTools should be shared between multiple elements
 
-    tooltip: str
+    tooltip : str
         An optional tooltip to override the default
 
-    vertex_style: dict
+    vertex_style : dict
         A dictionary specifying the style options for the vertices.
         The usual bokeh style options apply, e.g. fill_color,
         line_alpha, size, etc.
