@@ -1,4 +1,5 @@
 import datetime as dt
+from contextlib import suppress
 from unittest import SkipTest, skipIf
 
 import colorcet as cc
@@ -30,6 +31,7 @@ from holoviews import (
     Spikes,
     Spread,
     TriMesh,
+    renderer,
 )
 from holoviews.element.comparison import ComparisonTestCase
 from holoviews.operation import apply_when
@@ -206,12 +208,15 @@ class DatashaderAggregateTests(ComparisonTestCase):
         points = Points([(0.2, 0.3, 'A'), (0.4, 0.7, 'B'), (0, 0.99, 'C')], vdims='z')
         img = aggregate(points, dynamic=False,  x_range=(0, 0), y_range=(0, 1),
                         aggregator=ds.count_cat('z'), height=2)
-        xs, ys = [], [0.25, 0.75]
-        params = dict(bounds=(0, 0, 0, 1), xdensity=1)
-        expected = NdOverlay({'A': Image((xs, ys, np.zeros((2, 0))), vdims=Dimension('z Count', nodata=0), **params),
-                              'B': Image((xs, ys, np.zeros((2, 0))), vdims=Dimension('z Count', nodata=0), **params),
-                              'C': Image((xs, ys, np.zeros((2, 0))), vdims=Dimension('z Count', nodata=0), **params)},
-                             kdims=['z'])
+        expected = ImageStack(
+            xr.Dataset(
+                {"z Count": (("y", "x"), [[], []])},
+                coords={"x": [], "y": [0.25, 0.75]},
+            ),
+            vdims=Dimension('z Count', nodata=0),
+            bounds=(0, 0, 0, 1),
+            xdensity=1
+        )
         self.assertEqual(img, expected)
 
     def test_aggregate_curve(self):
@@ -272,18 +277,25 @@ class DatashaderAggregateTests(ComparisonTestCase):
         curve = Curve((dates, [1, 2, 3]))
         curve2 = Curve((dates, [3, 2, 1]))
         ndoverlay = NdOverlay({0: curve, 1: curve2}, 'Cat')
-        imgs = aggregate(ndoverlay, aggregator=ds.count_cat('Cat'), width=2, height=2,
+        img = aggregate(ndoverlay, aggregator=ds.count_cat('Cat'), width=2, height=2,
                          x_range=(xstart, xend), dynamic=False)
-        bounds = (np.datetime64('2015-12-31T23:59:59.723518'), 1.0,
-                  np.datetime64('2016-01-03T00:00:00.276482'), 3.0)
-        dates = [np.datetime64('2016-01-01T11:59:59.861759000',),
-                 np.datetime64('2016-01-02T12:00:00.138241000')]
-        expected = Image((dates, [1.5, 2.5], [[1, 0], [0, 2]]),
-                         datatype=['xarray'], bounds=bounds, vdims=Dimension('Count', nodata=0))
-        expected2 = Image((dates, [1.5, 2.5], [[0, 1], [1, 1]]),
-                         datatype=['xarray'], bounds=bounds, vdims=Dimension('Count', nodata=0))
-        self.assertEqual(imgs[0], expected)
-        self.assertEqual(imgs[1], expected2)
+        assert isinstance(img, ImageStack)
+        x = pd.date_range(xstart, xend, periods=4).to_numpy()
+        y = np.array([1.25, 1.75, 2.25, 2.75])
+        cat = np.array([0.0, 1.0])
+        a = np.array([
+            [[1, 0], [0, 0], [0, 0], [0, 1]],
+            [[0, 0], [1, 0], [0, 1], [0, 0]],
+            [[0, 0], [0, 1], [1, 1], [0, 0]],
+            [[0, 1], [0, 0], [0, 0], [1, 0]],
+        ], dtype=np.uint32)
+        xrds = xr.DataArray(
+            a,
+            dims=('y', 'x', 'Cat'),
+            coords={"y": y, "Cat": cat, "x": x}
+        )
+        expected = ImageStack(xrds, kdims=["x", "y"], vdims=["0.0", "1.0"])
+        assert (expected.data == a).all()
 
     def test_aggregate_dt_xaxis_constant_yaxis(self):
         df = pd.DataFrame({'y': np.ones(100)}, index=pd.date_range('1980-01-01', periods=100, freq='1min'))
@@ -873,12 +885,12 @@ class DatashaderShadeTests(ComparisonTestCase):
                                      datatype=['xarray'], vdims=Dimension('z Count', nodata=0))},
                          kdims=['z'])
         shaded = shade(data, rescale_discrete_levels=False)
-        r = [[228, 120], [66, 120]]
-        g = [[26, 109], [150, 109]]
-        b = [[28, 95], [129, 95]]
+        r = [[228, 0], [66, 0]]
+        g = [[26, 0], [150, 0]]
+        b = [[28, 0], [129, 0]]
         a = [[40, 0], [255, 0]]
         expected = RGB((xs, ys, r, g, b, a), datatype=['grid'],
-                       vdims=RGB.vdims+[Dimension('A', range=(0, 1))])
+                       vdims=[*RGB.vdims, Dimension('A', range=(0, 1))])
         self.assertEqual(shaded, expected)
 
     def test_shade_categorical_images_grid(self):
@@ -891,12 +903,12 @@ class DatashaderShadeTests(ComparisonTestCase):
                                      datatype=['grid'], vdims=Dimension('z Count', nodata=0))},
                          kdims=['z'])
         shaded = shade(data, rescale_discrete_levels=False)
-        r = [[228, 120], [66, 120]]
-        g = [[26, 109], [150, 109]]
-        b = [[28, 95], [129, 95]]
+        r = [[228, 0], [66, 0]]
+        g = [[26, 0], [150, 0]]
+        b = [[28, 0], [129, 0]]
         a = [[40, 0], [255, 0]]
         expected = RGB((xs, ys, r, g, b, a), datatype=['grid'],
-                       vdims=RGB.vdims+[Dimension('A', range=(0, 1))])
+                       vdims=[*RGB.vdims, Dimension('A', range=(0, 1))])
         self.assertEqual(shaded, expected)
 
     def test_shade_dt_xaxis_constant_yaxis(self):
@@ -1334,7 +1346,7 @@ def test_rasterize_where_agg_no_column(point_plot, agg_input_fn, index_col):
     img = rasterize(point_plot, aggregator=agg_fn, **rast_input)
 
     assert list(img.data) == ["__index__", "s", "val", "cat"]
-    assert list(img.vdims) == ["val", "s", "cat"]  # val first and no index
+    assert list(img.vdims) == ["val", "s", "cat"]  # val first and no __index__
 
     # N=100 in point_data is chosen to have a big enough sample size
     # so that the index are not the same for the different agg_input_fn
@@ -1371,26 +1383,88 @@ def test_rasterize_summerize(point_plot):
 
 
 @pytest.mark.parametrize("sel_fn", (ds.first, ds.last, ds.min, ds.max))
-def test_rasterize_selector(point_plot, sel_fn):
-    rast_input = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=2, height=2)
-    img = rasterize(point_plot, selector=sel_fn("val"), **rast_input)
+def test_selector_rasterize(point_plot, sel_fn):
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+    img = rasterize(point_plot, selector=sel_fn("val"), **inputs)
 
     # Count is from the aggregator
     assert list(img.data) == ["Count", "__index__", "s", "val", "cat"]
-    assert list(img.vdims) == ["Count", "s", "val", "cat"]  # no index
+    assert list(img.vdims) == [Dimension("Count")]  # Only the dimension send to the frontend
 
     # The output for the selector should be equal to the output for the aggregator using
     # ds.where
-    img_agg = rasterize(point_plot, aggregator=ds.where(sel_fn("val")), **rast_input)
+    img_agg = rasterize(point_plot, aggregator=ds.where(sel_fn("val")), **inputs)
     for c in ["s", "val", "cat"]:
-        np.testing.assert_array_equal(img[c], img_agg[c])
+        np.testing.assert_array_equal(img.data[c], img_agg.data[c], err_msg=c)
 
     # Checking the count is also the same
-    img_count = rasterize(point_plot, **rast_input)
+    img_count = rasterize(point_plot, **inputs)
     np.testing.assert_array_equal(img["Count"], img_count["Count"])
 
 
-def test_rasterize_with_datetime_column():
+@pytest.mark.parametrize("sel_fn", (ds.first, ds.last, ds.min, ds.max))
+def test_selector_rasterize_empty_selector(point_plot, sel_fn):
+    point_plot.data["index_col"] = point_plot.data.index
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+    # Empty selector will use index
+    img = rasterize(point_plot, selector=sel_fn(), **inputs)
+    exp = rasterize(point_plot, selector=sel_fn("index_col"), **inputs)
+
+    for c in ["s", "val", "cat", "index_col"]:
+        np.testing.assert_array_equal(img.data[c], exp.data[c], err_msg=c)
+
+
+@pytest.mark.usefixtures("bokeh_backend")
+def test_selector_hover_in_overlay(point_plot):
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+    overlay = rasterize(point_plot, selector=ds.first("val"), **inputs).opts(tools=["hover"]) * Points([])
+    renderer("bokeh").get_plot(overlay)
+
+@pytest.mark.parametrize("sel_fn", (ds.first, ds.last, ds.min, ds.max))
+def test_selector_datashade(point_plot, sel_fn):
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+    img = datashade(point_plot, selector=sel_fn("val"), **inputs)
+
+    # RGBA is from the aggregator
+    assert list(img.data) == [*"RGBA", "__index__", "s", "val", "cat"]
+    assert list(img.vdims) == [*map(Dimension, "RGBA")]  # Only the RGBA send to the frontend
+
+    # The output for the selector should be equal to the output for the aggregator using
+    # ds.where
+    img_agg = rasterize(point_plot, aggregator=ds.where(sel_fn("val")), **inputs)
+    for c in ["s", "val", "cat"]:
+        np.testing.assert_array_equal(img.data[c], img_agg.data[c], err_msg=c)
+
+    # Checking the RGBA is also the same
+    img_count = datashade(point_plot, **inputs)
+    for n in "RGBA":
+        np.testing.assert_array_equal(img[n], img_count[n], err_msg=n)
+
+
+@pytest.mark.parametrize("op_fn", (rasterize, datashade))
+@pytest.mark.parametrize(
+    "agg_fn", (ds.count(), ds.by("cat")), ids=["count", "by"]
+)
+def test_selector_spread(point_plot, op_fn, agg_fn):
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+    img = op_fn(point_plot, aggregator=agg_fn, selector=ds.first("val"), **inputs)
+    spread_img = spread(img)
+
+    with suppress(AssertionError): # We expect them to be different
+        xr.testing.assert_equal(spread_img.data, img.data)
+        raise ValueError("The spread should not be equal to the original image")
+
+    with suppress(AssertionError): # We expect them to be different
+        np.testing.assert_array_equal(spread_img.data["__index__"], img.data["__index__"])
+        raise ValueError("The spread should not be equal to the original image")
+
+    data_nan = np.all([spread_img.data[v.name] == 0 for v in spread_img.vdims], axis=0)
+    index_nan = spread_img.data["__index__"] == -1
+    assert index_nan.sum() == 36  # Hard-coded
+    np.testing.assert_array_equal(data_nan, index_nan)
+
+
+def test_selector_rasterize_with_datetime_column():
     n = 4
     df = pd.DataFrame({
         "x": np.random.uniform(-180, 180, n),
@@ -1402,9 +1476,30 @@ def test_rasterize_with_datetime_column():
     rast_input = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=2, height=2)
     img_agg = rasterize(point_plot, selector=ds.first("Value"), **rast_input)
 
-    assert img_agg["Timestamp"].dtype == np.dtype("datetime64[ns]")
+    assert img_agg.data["Timestamp"].dtype == np.dtype("datetime64[ns]")
 
 
+def test_selector_datashade_bad_column_name(point_data):
+    point_data = point_data.rename({"cat": "R"}, axis=1)
+    assert "R" in point_data.columns
+
+    point_plot = Points(point_data)
+    inputs = dict(dynamic=False,  x_range=(-1, 1), y_range=(-1, 1), width=10, height=10)
+
+    msg = "Cannot use 'R', 'G', 'B', or 'A' as columns, when using datashade with selector"
+    with pytest.raises(ValueError, match=msg):
+        datashade(point_plot, selector=ds.min("val"), **inputs)
+
+
+@pytest.mark.usefixtures("bokeh_backend")
+def test_selector_single_categorical():
+    # Test for https://github.com/holoviz/holoviews/issues/6595
+    plot = Points(([0, 1], [0, 1], ["A", "A"]), ["X", "Y"], "C")
+    plot = rasterize(plot, aggregator=ds.count_cat("C"), selector=ds.first("X"))
+    plot = dynspread(plot)
+    # Should not fail
+    renderer("bokeh").get_plot(plot)
+
 
 class DatashaderSpreadTests(ComparisonTestCase):
 
