@@ -1,4 +1,5 @@
 import datetime as dt
+import random
 from importlib.util import find_spec
 from unittest import SkipTest, skipIf
 
@@ -22,14 +23,19 @@ except ImportError:
     cudf = None
 
 from holoviews import (
+    AdjointLayout,
     Area,
     Contours,
     Curve,
     Dataset,
+    Dendrogram,
+    Empty,
     GridSpace,
+    HeatMap,
     Histogram,
     HoloMap,
     Image,
+    Layout,
     NdLayout,
     NdOverlay,
     Points,
@@ -42,6 +48,7 @@ from holoviews.element.comparison import ComparisonTestCase
 from holoviews.operation.element import (
     contours,
     decimate,
+    dendrogram,
     gradient,
     histogram,
     interpolate_curve,
@@ -593,6 +600,25 @@ class OperationTests(ComparisonTestCase):
         hist = Histogram(([1.,  4., 7.5], [0, 3, 6, 9]), vdims=['y'])
         self.assertEqual(op_hist, hist)
 
+    @pytest.mark.usefixtures("mpl_backend")
+    def test_histogram_dask_array_mpl(self):
+        # Regression test for https://github.com/holoviz/holoviews/issues/5111
+        dd = pytest.importorskip("dask.dataframe")
+
+        data = {
+            "carrier": ["A", "A", "A", "A", "B", "B", "B", "B", "B"],
+            "depdelay": [127.0, 3.0, -3.0, 19.0, 264.0, -6.0, 1.0, 2.0, 83.0],
+        }
+        flights = dd.from_pandas(pd.DataFrame(data), npartitions=2)
+
+        by = "carrier"
+        ds = Dataset(flights, by)
+        ds_grouped = ds.groupby(by)
+        hists = histogram(ds_grouped, dimension="depdelay")
+
+        # Should not error
+        renderer("matplotlib").get_plot(hists)
+
     def test_interpolate_curve_pre(self):
         interpolated = interpolate_curve(Curve([0, 0.5, 1]), interpolation='steps-pre')
         curve = Curve([(0, 0), (0, 0.5), (1, 0.5), (1, 1), (2, 1)])
@@ -702,3 +728,148 @@ class OperationTests(ComparisonTestCase):
 
         index = decimated.data[()].data.index
         assert np.all(index == np.sort(index))
+
+
+class TestDendrogramOperation:
+
+    @pytest.mark.usefixtures("bokeh_backend")
+    def setup_class(self):
+        pytest.importorskip("scipy")
+
+        random.seed(1)
+        self.df = pd.DataFrame(
+            [(i, chr(65 + j), random.random()) for j in range(10) for i in range(5)],
+            columns=["z", "x", "y"],
+        )
+        data = [
+            [7, 8, 0, 0, 0, 0],
+            [8, 6, 0, 0, 0, 0],
+            [0, 0, 9, 8, 2, 7],
+            [0, 0, 0, 1, 8, 2],
+            [0, 7, 0, 7, 0, 0],
+        ]
+        self.df2 = pd.DataFrame([
+            {"cluster": f"clust {i}", "gene": f"gene {j}", "value": data[i][j]}
+            for j in range(6)
+            for i in range(5)
+        ])
+        self.bokeh_renderer = renderer("bokeh")
+
+    def get_childrens(self, adjoint):
+        bk_childrens = self.bokeh_renderer.get_plot(adjoint).handles["plot"].children
+        (atop, *_), (amain, *_), (aright, *_) = bk_childrens
+        top = self.bokeh_renderer.get_plot(adjoint["top"]).handles["plot"]
+        main = self.bokeh_renderer.get_plot(adjoint["main"]).handles["plot"]
+        right = self.bokeh_renderer.get_plot(adjoint["right"]).handles["plot"]
+        return (atop, amain, aright), (top, main, right)
+
+    def test_right_only(self):
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["x"], main_dim="y")
+        assert isinstance(dendro, AdjointLayout)
+        assert isinstance(dendro["main"], HeatMap)
+        assert isinstance(dendro["right"], Dendrogram)
+        assert isinstance(dendro["top"], Empty)
+        assert dendro["right"].kdims == ["__dendrogram_x_x", "__dendrogram_y_x"]
+
+    def test_top_only(self):
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["z"], main_dim="y")
+        assert isinstance(dendro, AdjointLayout)
+        assert isinstance(dendro["main"], HeatMap)
+        assert isinstance(dendro["right"], Empty)
+        assert isinstance(dendro["top"], Dendrogram)
+        assert dendro["top"].kdims == ["__dendrogram_x_z", "__dendrogram_y_z"]
+
+    @pytest.mark.parametrize("adjoint_dims", [["x", "z"], ["z", "x"]], ids=["xz", "zx"])
+    def test_both_xz(self, adjoint_dims):
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=adjoint_dims, main_dim="y")
+        assert isinstance(dendro, AdjointLayout)
+        assert isinstance(dendro["main"], HeatMap)
+        assert isinstance(dendro["right"], Dendrogram)
+        assert isinstance(dendro["top"], Dendrogram)
+        assert dendro["right"].kdims == ["__dendrogram_x_x", "__dendrogram_y_x"]
+        assert dendro["top"].kdims == ["__dendrogram_x_z", "__dendrogram_y_z"]
+
+    def test_point_plot(self):
+        dataset = Points(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["x", "z"], main_dim="y")
+        assert isinstance(dendro, AdjointLayout)
+        assert isinstance(dendro["main"], Points)
+
+    def test_depth_matches_non_adjoint(self):
+        # depth dimensions is the orthogonal axis to the main plot
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["x", "z"], main_dim="y")
+        (atop, amain, aright), (top, main, right) = self.get_childrens(dendro)
+
+        # Verify no shared axis is changing the depth dimension of the right
+        assert atop.y_range.start == top.y_range.start
+        assert atop.y_range.end == top.y_range.end
+        assert atop.y_range.end == top.y_range.end
+
+        # These should be shared with the main plot
+        assert atop.x_range.start == amain.x_range.start
+        assert atop.x_range.end == amain.x_range.end
+
+        # Verify no shared axis is changing the depth dimension of the right
+        assert aright.x_range.start == right.y_range.start
+        assert aright.x_range.end == right.y_range.end
+
+        # These should be shared with the main plot
+        assert aright.y_range.factors == amain.y_range.factors
+
+    def test_adjoned_False_1dim(self):
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["x"], main_dim="y", adjoined=False)
+
+        assert isinstance(dendro, Dendrogram)
+
+    def test_adjoned_False_2dim(self):
+        dataset = Dataset(self.df)
+        dendro = dendrogram(dataset, adjoint_dims=["x", "z"], main_dim="y", adjoined=False)
+
+        assert isinstance(dendro, Layout)
+        assert len(dendro) == 2
+        assert isinstance(dendro[0], Dendrogram)
+        assert isinstance(dendro[1], Dendrogram)
+
+    @pytest.mark.parametrize(
+        "adjoint_dims",
+        (["cluster"], ["gene"], ["gene", "cluster"]),
+        ids=["right", "top", "both"],
+    )
+    def test_invert_dendrogram(self, adjoint_dims):
+        plot = Points(self.df2, kdims=["gene", "cluster"])
+        dendro1 = dendrogram(plot, adjoint_dims=adjoint_dims, main_dim="value")
+        dendro2 = dendrogram(plot, adjoint_dims=adjoint_dims, main_dim="value", invert=True)
+
+        main1 = self.bokeh_renderer.get_plot(dendro1["main"]).handles["plot"]
+        main2 = self.bokeh_renderer.get_plot(dendro2["main"]).handles["plot"]
+
+        match adjoint_dims:
+            case ["cluster"]:
+                assert main1.x_range.factors == main2.x_range.factors
+                assert main1.y_range.factors == main2.y_range.factors[::-1]
+            case ["gene"]:
+                assert main1.x_range.factors == main2.x_range.factors[::-1]
+                assert main1.y_range.factors == main2.y_range.factors
+            case _:
+                assert main1.y_range.factors == main2.y_range.factors[::-1]
+                assert main1.x_range.factors == main2.x_range.factors[::-1]
+
+    @pytest.mark.parametrize("adjoint_dims", (["cluster"], ["gene"],), ids=["right", "top"])
+    def test_assure_non_adjoined_axis_is_unchanged(self, adjoint_dims):
+        # See: https://github.com/holoviz/holoviews/pull/6625#issuecomment-2981268665
+        plot = Points(self.df2, kdims=["gene", "cluster"])
+        main1 = self.bokeh_renderer.get_plot(plot).handles["plot"]
+
+        dendro = dendrogram(plot, adjoint_dims=adjoint_dims, main_dim="value")
+        main2 = self.bokeh_renderer.get_plot(dendro["main"]).handles["plot"]
+
+        match adjoint_dims:
+            case ["cluster"]:
+                assert main1.x_range.factors == main2.x_range.factors
+            case ["gene"]:
+                assert main1.y_range.factors == main2.y_range.factors
