@@ -3,8 +3,9 @@ from collections import deque
 import numpy as np
 import pandas as pd
 
+from holoviews.core.dimension import Dimension
 from holoviews.core.spaces import DynamicMap
-from holoviews.element import Curve, Path3D, Scatter3D
+from holoviews.element import Curve, Path3D, Scatter, Scatter3D
 from holoviews.streams import PointerX
 
 from .test_plot import TestPlotlyPlot, plotly_renderer
@@ -232,6 +233,7 @@ class TestOverlayPlot(TestPlotlyPlot):
         self.assertEqual(state['layout']['scene']['zaxis']['title']['text'], 'Z-Axis')
 
 class TestColorbarPlot(TestPlotlyPlot):
+
     def test_base(self):
         df = pd.DataFrame(np.random.random((10, 4)), columns=list("XYZT"))
         scatter = Scatter3D(data=df)
@@ -255,3 +257,11 @@ class TestColorbarPlot(TestPlotlyPlot):
         state = self._get_plot_state(scatter)
         assert "colorbar" in state["data"][0]["marker"]
         assert state["data"][0]["marker"]["colorbar"]["title"]["text"] == "some-title"
+
+    def test_style_map_dimension_object(self):
+        x = Dimension("x")
+        y = Dimension("y")
+        scatter = Scatter([1, 2, 3], kdims=[x], vdims=[y]).opts(color=x)
+        state = self._get_plot_state(scatter)
+        assert state["data"][0]["marker"]["cmin"] == 0
+        assert state["data"][0]["marker"]["cmax"] == 2
